@@ -17,31 +17,24 @@ from PIL import Image, ImageFont, ImageDraw
 
 from Sort.yolo3.model import yolo_eval
 from Sort.yolo3.utils import letterbox_image
-import argparse
-
-pwd = os.path.abspath(os.path.dirname(__file__))
-ap = argparse.ArgumentParser()
-ap.add_argument("-i", "--input", help="path to input video", default=str(pwd).join("/test_video"
-                                                                                   "/det_t1_video_00315_test.avi"))
-ap.add_argument("-c", "--class", help="name of class", default="person")
-args = vars(ap.parse_args())
 
 
 class YOLO(object):
-    def __init__(self):
-        self.model_path = pwd + '/model_data/yolo.h5'
-        self.anchors_path = pwd + '/model_data/yolo_anchors.txt'
-        self.classes_path = pwd + '/model_data/coco_classes.txt'
+    def __init__(self, model_path, anchors_path, classes_path, model_type):
+        self.model_path = model_path
+        self.anchors_path = anchors_path
+        self.classes_path = classes_path
+        self.model_type = model_type
         # 具体参数可实验后进行调整
-        if args["class"] == 'person':
+        if model_type == 'person':
             self.score = 0.6  # 0.8
             self.iou = 0.6
             self.model_image_size = (416, 416)
-        if args["class"] == 'car':
+        if model_type == 'car':
             self.score = 0.6
             self.iou = 0.6
             self.model_image_size = (416, 416)
-        if args["class"] == 'bicycle' or args["class"] == 'motorcycle':
+        if model_type == 'bicycle' or model_type == 'motorcycle':
             self.score = 0.6
             self.iou = 0.6
             self.model_image_size = (416, 416)
@@ -127,7 +120,7 @@ class YOLO(object):
                print(predicted_class)
                continue
             '''
-            if predicted_class != args["class"]:
+            if predicted_class != self.model_type:
                 # print(predicted_class)
                 continue
 
